==> prestashop_1.5.0.15.zip: prestashop/modules/blockcms/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'Bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_cdca12007979fc49008fd125cdb775fc'] = 'Ajoute un bloc contenant plusieurs lien vers vos pages CMS';
$_MODULE['<{blockcms}prestashop>blockcms_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{blockcms}prestashop>blockcms_ef61fb324d729c341ea8ab9901e23566'] = 'Ajouter un bloc';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{blockcms}prestashop>blockcms_97390dd0b5ba7867120aee2ff22bfa38'] = 'Configuration du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_94ff014237f6f5cbf5c3655f5ef513c9'] = 'Blocs CMS';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Configuration des liens CMS en pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_48566f492af8fd2346b20dbd32168476'] = 'Lien de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_0b31e765f1e9cb451319b32e84a75a9e'] = 'Sélectionnez les pages que vous souhaitez afficher dans le bloc CMS de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_6c5f7d2f911e91ebd0c077fe770e739e'] = 'Informations de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_32c532e462a1f85b1b103ed9989a1aba'] = 'Afficher \"Propulsé par PrestaShop\"';
$_MODULE['<{blockcms}prestashop>blockcms_6e95f87c9d99340ea0945d8b528f22d1'] = 'Afficher les informations du pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_38fb7d24e0d60a048f540ecb18e13376'] = 'Enregistrer';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'Configuration du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'Modification du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'Nouveau bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_ab278feec882a679b078490639232d69'] = 'Nom du bloc';
$_MODULE['<{blockcms}prestashop>blockcms_bdbaef442c586e1bbecb44eba1ba7e2d'] = 'Si vous laissez ce champ vide, le nom du bloc sera le nom de la catégorie';
$_MODULE['<{blockcms}prestashop>blockcms_fca0206c8afc8d67969f9aec20e3287e'] = 'Catégorie du CMS :';
$_MODULE['<{blockcms}prestashop>blockcms_abf9012e9560b3c44a536f5c4a2a0b62'] = 'Emplacement :';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Gauche';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Droite';
$_MODULE['<{blockcms}prestashop>blockcms_5e2b11203c9a4ac0ec01e7bb31e256f6'] = 'Afficher les magasins';
$_MODULE['<{blockcms}prestashop>blockcms_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{blockcms}prestashop>blockcms_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{blockcms}prestashop>blockcms_08f3899ad165f85f8596199966b8c673'] = 'Afficher \"Nos magasins\" en bas du block';
$_MODULE['<{blockcms}prestashop>blockcms_55737e084beaa370a127f3f031f1932e'] = 'Contenu du CMS :';
$_MODULE['<{blockcms}prestashop>blockcms_4d388b3442c6b155f0613fda97b1369a'] = 'Sélectionnez les pages que vous souhaitez afficher dans ce bloc';
$_MODULE['<{blockcms}prestashop>blockcms_3cd97b7a82d531d009884f9633a007cc'] = 'Valeur d\'affichage non valable pour le magasin';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Emplacement non valable pour le bloc';
$_MODULE['<{blockcms}prestashop>blockcms_92fc29650a0f9dd3fca4e5de1845f78b'] = 'Vous devez choisir au moins une page ou sous-catégorie pour créer un bloc CMS.';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Page ou catégorie CMS non valable';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Le nom du bloc est trop long';
$_MODULE['<{blockcms}prestashop>blockcms_ede67d50014846cb8bb1b00d5fde77be'] = 'Identifiant non valable pour le bloc du CMS';
$_MODULE['<{blockcms}prestashop>blockcms_7ab6862bda9343553ef49bffb7a4f73c'] = 'Veuillez fournir un text de pied de page pour la langue par défaut';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Activation non valable pour le pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_467efc7b3308cc86cd3e142be9be2189'] = 'Vous ne pouvez pas créer un nouveau bloc !';
$_MODULE['<{blockcms}prestashop>blockcms_5dab5acc3c6a2a7e87e8d8926a2c763e'] = 'Erreur : vous essayez de supprimer un bloc CMS inexistant';
$_MODULE['<{blockcms}prestashop>blockcms_963b266405940fb5063673d6c1d6f262'] = 'Informations du pied de page mises à jour';
$_MODULE['<{blockcms}prestashop>blockcms_ddd7d8a072783afaf23e5e6843398fc9'] = 'Le bloc CMS a bien été ajouté';
$_MODULE['<{blockcms}prestashop>blockcms_31a22821c66edf7e3aa33ef1c8109f4c'] = 'Le bloc CMS a bien été modifié';
$_MODULE['<{blockcms}prestashop>blockcms_87a2663d841b78f01c27c0edb4f50b76'] = 'Suppression réussie';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Nos magasins';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Promotions';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Nouveaux produits';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Meilleures ventes';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Contactez-nous';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Propulsé par';
$_MODULE['<{blockcms}prestashop>form_4dabfa54822012dfc78d6ef40f224173'] = 'Blocs à gauche';
$_MODULE['<{blockcms}prestashop>form_d9ca3009e18447d91cd2e324e8e680ce'] = 'Blocs à droite';
$_MODULE['<{blockcms}prestashop>form_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>form_aae551ce0c29dfe39b0ff20139abdef3'] = 'Nom du bloc';
$_MODULE['<{blockcms}prestashop>form_bb34a159a88035cce7ef1607e7907f8f'] = 'Nom de la catégorie';
$_MODULE['<{blockcms}prestashop>form_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{blockcms}prestashop>form_06df33001c1d7187fdd81ea1f5b277aa'] = 'Actions';
$_MODULE['<{blockcms}prestashop>form_08a38277b0309070706f6652eeae9a53'] = 'Descendre';
$_MODULE['<{blockcms}prestashop>form_258f49887ef8d14ac268c92b02503aaa'] = 'Monter';
$_MODULE['<{blockcms}prestashop>form_7dce122004969d56ae2e0245cb754d35'] = 'Modifier';
$_MODULE['<{blockcms}prestashop>form_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{blockcms}prestashop>form_49ee3087348e8d44e1feda1917443987'] = 'Nom';
$_MODULE['<{blockcms}prestashop>form_288af9ab7bf1ea82c86597d0adc2de31'] = 'Aucune page créée';

==> prestashop_1.5.0.17.zip: prestashop/modules/blockcms/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'Bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_cdca12007979fc49008fd125cdb775fc'] = 'Ajoute un bloc contenant plusieurs lien vers vos pages CMS';
$_MODULE['<{blockcms}prestashop>blockcms_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{blockcms}prestashop>blockcms_ef61fb324d729c341ea8ab9901e23566'] = 'Ajouter un bloc';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{blockcms}prestashop>blockcms_97390dd0b5ba7867120aee2ff22bfa38'] = 'Configuration du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_94ff014237f6f5cbf5c3655f5ef513c9'] = 'Blocs CMS';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Configuration des liens CMS en pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_89887a6d62110cbd72c15218a2d0fda9'] = 'Afficher les liens d\'informations dans le pied de page.';
$_MODULE['<{blockcms}prestashop>blockcms_48566f492af8fd2346b20dbd32168476'] = 'Lien de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_0b31e765f1e9cb451319b32e84a75a9e'] = 'Sélectionnez les pages que vous souhaitez afficher dans le bloc CMS de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_6c5f7d2f911e91ebd0c077fe770e739e'] = 'Informations de pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_32c532e462a1f85b1b103ed9989a1aba'] = 'Afficher \"Propulsé par PrestaShop\"';
$_MODULE['<{blockcms}prestashop>blockcms_38fb7d24e0d60a048f540ecb18e13376'] = 'Enregistrer';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'Configuration du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'Modification du bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'Nouveau bloc CMS';
$_MODULE['<{blockcms}prestashop>blockcms_ab278feec882a679b078490639232d69'] = 'Nom du bloc';
$_MODULE['<{blockcms}prestashop>blockcms_bdbaef442c586e1bbecb44eba1ba7e2d'] = 'Si vous laissez ce champ vide, le nom du bloc sera le nom de la catégorie';
$_MODULE['<{blockcms}prestashop>blockcms_fca0206c8afc8d67969f9aec20e3287e'] = 'Catégorie du CMS :';
$_MODULE['<{blockcms}prestashop>blockcms_abf9012e9560b3c44a536f5c4a2a0b62'] = 'Emplacement :';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Gauche';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Droite';
$_MODULE['<{blockcms}prestashop>blockcms_5e2b11203c9a4ac0ec01e7bb31e256f6'] = 'Afficher les magasins';
$_MODULE['<{blockcms}prestashop>blockcms_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{blockcms}prestashop>blockcms_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{blockcms}prestashop>blockcms_08f3899ad165f85f8596199966b8c673'] = 'Afficher \"Nos magasins\" en bas du block';
$_MODULE['<{blockcms}prestashop>blockcms_55737e084beaa370a127f3f031f1932e'] = 'Contenu du CMS :';
$_MODULE['<{blockcms}prestashop>blockcms_4d388b3442c6b155f0613fda97b1369a'] = 'Sélectionnez les pages que vous souhaitez afficher dans ce bloc';
$_MODULE['<{blockcms}prestashop>blockcms_3cd97b7a82d531d009884f9633a007cc'] = 'Valeur d\'affichage non valable pour le magasin';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Emplacement non valable pour le bloc';
$_MODULE['<{blockcms}prestashop>blockcms_92fc29650a0f9dd3fca4e5de1845f78b'] = 'Vous devez choisir au moins une page ou sous-catégorie pour créer un bloc CMS.';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Page ou catégorie CMS non valable';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Le nom du bloc est trop long';
$_MODULE['<{blockcms}prestashop>blockcms_ede67d50014846cb8bb1b00d5fde77be'] = 'Identifiant non valable pour le bloc du CMS';
$_MODULE['<{blockcms}prestashop>blockcms_7ab6862bda9343553ef49bffb7a4f73c'] = 'Veuillez fournir un text de pied de page pour la langue par défaut';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Activation non valable pour le pied de page';
$_MODULE['<{blockcms}prestashop>blockcms_467efc7b3308cc86cd3e142be9be2189'] = 'Vous ne pouvez pas créer un nouveau bloc !';
$_MODULE['<{blockcms}prestashop>blockcms_5dab5acc3c6a2a7e87e8d8926a2c763e'] = 'Erreur : vous essayez de supprimer un bloc CMS inexistant';
$_MODULE['<{blockcms}prestashop>blockcms_963b266405940fb5063673d6c1d6f262'] = 'Informations du pied de page mises à jour';
$_MODULE['<{blockcms}prestashop>blockcms_ddd7d8a072783afaf23e5e6843398fc9'] = 'Le bloc CMS a bien été ajouté';
$_MODULE['<{blockcms}prestashop>blockcms_31a22821c66edf7e3aa33ef1c8109f4c'] = 'Le bloc CMS a bien été modifié';
$_MODULE['<{blockcms}prestashop>blockcms_87a2663d841b78f01c27c0edb4f50b76'] = 'Suppression réussie';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Nos magasins';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Promotions';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Nouveaux produits';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Meilleures ventes';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Contactez-nous';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Propulsé par';
$_MODULE['<{blockcms}prestashop>form_4dabfa54822012dfc78d6ef40f224173'] = 'Blocs à gauche';
$_MODULE['<{blockcms}prestashop>form_d9ca3009e18447d91cd2e324e8e680ce'] = 'Blocs à droite';
$_MODULE['<{blockcms}prestashop>form_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>form_aae551ce0c29dfe39b0ff20139abdef3'] = 'Nom du bloc';
$_MODULE['<{blockcms}prestashop>form_bb34a159a88035cce7ef1607e7907f8f'] = 'Nom de la catégorie';
$_MODULE['<{blockcms}prestashop>form_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{blockcms}prestashop>form_06df33001c1d7187fdd81ea1f5b277aa'] = 'Actions';
$_MODULE['<{blockcms}prestashop>form_08a38277b0309070706f6652eeae9a53'] = 'Descendre';
$_MODULE['<{blockcms}prestashop>form_258f49887ef8d14ac268c92b02503aaa'] = 'Monter';
$_MODULE['<{blockcms}prestashop>form_7dce122004969d56ae2e0245cb754d35'] = 'Modifier';
$_MODULE['<{blockcms}prestashop>form_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{blockcms}prestashop>form_49ee3087348e8d44e1feda1917443987'] = 'Nom';
$_MODULE['<{blockcms}prestashop>form_288af9ab7bf1ea82c86597d0adc2de31'] = 'Aucune page créée';
